@@ -8,10 +8,12 @@ def get_data(department, municipality):
     department = department.lower()
     municipality=municipality.lower()
 
-    department = get_less_distant_item(department, departments.keys())
+    department, department_distance = get_less_distant_item(
+        department, departments.keys())
 
     municipalities = departments[department]['municipalities']
-    municipality = get_less_distant_item(municipality, municipalities.keys())
+    municipality, municipality_distance = get_less_distant_item(
+        municipality, municipalities.keys())
 
 
     dane_code =  departments[department]['municipalities']\
@@ -20,8 +22,10 @@ def get_data(department, municipality):
     place_data = {
         "department":department,
         "department_code": departments[department]['dane_code'],
+        "department_levenshtein_distance": department_distance,
         "municipality":municipality,
         "municipality_code": dane_code,
+        "minicipality_levenshtein_distance": municipality_distance,
     }
 
     return place_data
@@ -32,13 +36,13 @@ def get_less_distant_item(to_compare, options):
 
     for option in options:
         distance = jellyfish.levenshtein_distance(to_compare, option)
-        
+
         if last_distance == None:
             last_distance = distance
         elif distance > last_distance:
             continue
-        
+
         last_distance = distance
         best_value = option
 
-    return best_value
+    return best_value, distance
