@@ -915,14 +915,41 @@ departments = {
         }
     },
     "Norte de Santander":{
-        "dane_code":"",
+        "dane_code":"54",
         "municipalities":{
+            "Bucarasica":{"dane_code":"54109"},
+            "El Tarra":{"dane_code":"54250"},
+            "Sardinata":{"dane_code":"54720"},
+            "Tibú":{"dane_code":"54810"},
+            "Abrego":{"dane_code":"54003"},
+            "Cachirá":{"dane_code":"54128"},
+            "Convención":{"dane_code":"54206"},
+            "El Carmen":{"dane_code":"54245"},
+            "Hacarí":{"dane_code":"54344"},
+            "La Esperanza":{"dane_code":"54385"},
+            "La Playa":{"dane_code":"54398"},
+            "Ocaña":{"dane_code":"54498"},
+            "San Calixto":{"dane_code":"54670"},
+            "Teorama":{"dane_code":"54800"},
+            "Cúcuta":{"dane_code":"54001"},
+            "El Zulia":{"dane_code":"54261"},
+            "Los Patios":{"dane_code":"54405"},
+            "Puerto Santander":{"dane_code":"54553"},
+            "San Cayetano":{"dane_code":"54673"},
+            "Villa Del Rosario":{"dane_code":"54874"},
+            "Cácota":{"dane_code":"54125"},
+            "Chitagá":{"dane_code":"54174"},
+            "Mutiscua":{"dane_code":"54480"},
             "Pamplona":{"dane_code":"54518"},
             "Pamplonita":{"dane_code":"54520"},
-            "Cúcuta":{"dane_code":"54001"},
-            "El Carmen":{"dane_code":"54245"},
-            "los patios":{"dane_code":"54405"},
-            "Ocaña":{"dane_code":"54498"},
+            "Silos":{"dane_code":"54743"},
+            "Bochalema":{"dane_code":"54099"},
+            "Chinácota":{"dane_code":"54172"},
+            "Durania":{"dane_code":"54239"},
+            "Herrán":{"dane_code":"54347"},
+            "Labateca":{"dane_code":"54377"},
+            "Ragonvalia":{"dane_code":"54599"},
+            "Toledo":{"dane_code":"54820"},
         }
     },
     "Putumayo":{
@@ -1279,4 +1306,4 @@ departments = {
             "San Andres":{"dane_code":"88001"},
         }
     }
-}
\ No newline at end of file
+}
